@@ -6,7 +6,10 @@ import json
 
 # 获取query参数
 def get_query_param(req: Request, key):
-    return req.args.get(key)
+    param = req.args.get(key)
+    if param is None:
+        raise Exception('param none')
+    return param
 
 
 # 获取query参数，不抛异常返回None
